PreAccountTransaction

Struct PreAccountTransaction 

pub struct PreAccountTransaction {
    pub header: TransactionHeader,
    pub payload: Payload,
    pub encoded: EncodedPayload,
    pub hash_to_sign: TransactionSignHash,
}
A transaction that is prepared to be signed. The serde instance serializes the structured payload and skips serializing the encoded one.

Fields

header: TransactionHeaderpayload: Payload

The payload.

encoded: EncodedPayload

The encoded payload. This is already serialized payload that is constructed during construction of the prepared transaction since we need it to compute the cost.

hash_to_sign: TransactionSignHash

Hash of the transaction to sign.

Implementations

Source

impl PreAccountTransaction

pub fn sign( self, signer: &impl TransactionSigner, ) -> AccountTransaction<EncodedPayload>

Sign the transaction with the provided signer. Note that this signer must match the account address and the number of keys that were used in construction, otherwise the transaction will be invalid.

pub fn extend(self) -> PreAccountTransactionV1

Extend a PreAccountTransaction to a PreAccountTransactionV1.