Function concordium_base::transactions::send::update_credential_keys
source · pub fn update_credential_keys(
signer: &impl ExactSizeTransactionSigner,
sender: AccountAddress,
nonce: Nonce,
expiry: TransactionTime,
num_existing_credentials: u16,
cred_id: CredentialRegistrationID,
keys: CredentialPublicKeys
) -> AccountTransaction<EncodedPayload>Expand description
Construct a transaction to update keys of a single credential on an account. The transaction specific arguments are
num_existing_credentials- the number of existing credentials on the account. This will affect the estimated transaction cost. It is safe to over-approximate this.cred_id-credIdof a credential whose keys are to be updated.keys- the new keys associated with the credential.