Enum concordium_base::base::ProtocolVersion
source · pub enum ProtocolVersion {
P1,
P2,
P3,
P4,
P5,
P6,
}Expand description
An enumeration of the supported versions of the consensus protocol. Binary and JSON serializations are as Word64 corresponding to the protocol number.
Variants
P1
The initial protocol version at mainnet launch.
P2
Protocol P2 introduces support for transfers with memos.
P3
Protocol P3 introduces support for account aliases. Each account can
now be referred to by 2^24 different addresses.
P4
Protocol P4 is a major upgrade that adds support for delegation,
baking pools, and V1 smart contracts.
P5
Protocol P5 is a minor upgrade that adds support for smart contract
upgradability, smart contract queries, relaxes some limitations and
improves the structure of internal node datastructures related to
accounts.
P6
Protocol P6 is a future protocol update that will introduce a new
consensus.